@@ -37,15 +37,24 @@ function el(tag, attrs, children) {
 }
 
 function formatComment(comment) {
-  return comment.split('\n').map(function (line) {
-    return line
-      .replace(/\t/g, '    ')
-      .replace(/ /g, '&nbsp;')
-      .replace(/`(.+?)`/g, function (match, code) {
-        return '<code>' + code + '</code>'
-      })
-  }).join('<br/>')
-
+  if (Object.prototype.toString.call(comment) !== '[object Array]') {
+    return comment
+  }
+  return comment.map(function (item) {
+    if (item.type === 'code') {
+      return '<pre><code>' + item.lines.join('') + '</code></pre>'
+    }
+    if (!$.trim(item.lines[0])) {
+      item.lines.shift()
+    }
+    return item.lines.map(function (line) {
+      return line.replace(/\t/g, '    ')
+        .replace(/ /g, '&nbsp;')
+        .replace(/`(.+?)`/g, function (match, code) {
+          return '<code>' + code + '</code>'
+        })
+    }).join('').replace(/\n/g, '<br/>')
+  }).join('')
 }
 
 function render(list, data) {
@@ -139,7 +148,10 @@ function goToAnchor() {
   }
 }
 
-function renderModule(data, moduleName, expanded) {
+function renderModule(routes, moduleName, expanded) {
+  routes.sort(function (item1, item2) {
+    return item1.path > item2.path ? 1 : -1
+  })
   var encodedModuleName = encodeURI(moduleName)
   return el('details', {
     open: expanded ? 'open' : undefined
@@ -161,15 +173,15 @@ function renderModule(data, moduleName, expanded) {
       el('span', {
         'class': 'route-count',
         title: '此模块中包含的路由数量'
-      }, '*' + data.length)
+      }, '*' + routes.length)
     ]),
     el(
       'ol',
       {'class': 'api-list'},
-      data.map(function (route) {
+      routes.map(function (route) {
           var id = route.method + '#' + route.path
           API_LIST[id] = route
-          var encodedRoutePath = encodeURI(route.path)
+          var encodedRoutePath = encodeURI(route.method + ':' + route.path)
           return el('li', {'class': 'api-item'}, [
             el('div', null, [
               el(
@@ -388,7 +400,6 @@ function renderArgs(args, editable, append) {
   }
 
   return el('table', {'class': 'args-table'}, [
-    el('caption', null, '参数信息'),
     el('colgroup', null, [
       el('col', {style: 'width: 200px'}, null),
       el('col', {style: 'width: 150px'}, null),
